import random
from django.contrib.auth.models import AbstractUser
from django.db import models
from django.utils.timezone import now, timedelta
from django.db.models.signals import post_save
from django.dispatch import receiver



class CustomUser(AbstractUser):
    
    class Meta:
        app_label = "authentication"
        verbose_name = "User Account"
        verbose_name_plural = "User Accounts"

class OTP(models.Model):
    user = models.OneToOneField(CustomUser, on_delete=models.CASCADE)
    code = models.CharField(max_length=6)
    expires_at = models.DateTimeField()

    @classmethod
    def generate_otp(cls, user):
        otp = str(random.randint(100000, 999999))
        expires_at = now() + timedelta(minutes=5)
        otp_obj, created = cls.objects.update_or_create(user=user, defaults={"code": otp, "expires_at": expires_at})
        return otp




@receiver(post_save, sender=OTP)
def cleanup_otps(sender, **kwargs):
    OTP.objects.filter(expires_at__lt=now()).delete()
