from django.contrib.auth import authenticate, login, logout
from django.shortcuts import render, redirect
from django.core.mail import send_mail
from django.conf import settings
from .models import OTP, CustomUser
from .forms import SignupForm, LoginForm, OTPForm
from django.utils.timezone import now

def signup_view(request):
    if request.method == "POST":
        form = SignupForm(request.POST)
        if form.is_valid():
            user = form.save(commit=False)
            user.is_active = False
            user.save()

            otp_code = OTP.generate_otp(user)
            request.session["otp_user"] = user.id
            
            send_mail(
                "Your OTP Code",
                f"Your One-Time Password (OTP) is: {otp_code}",
                getattr(settings, "AUTH_EMAIL_SENDER"),
                [user.email],
            )
            return redirect(getattr(settings, "AUTH_REDIRECT_SIGNUP", "verify_otp"))

    else:
        form = SignupForm()
    
        return render(request, "authentication/signup.html", {"form": form})



def login_view(request):
    if request.method == "POST":
        form = LoginForm(request.POST)
        if form.is_valid():
            user = authenticate(
                username=form.cleaned_data["username"], 
                password=form.cleaned_data["password"]
            )
            if user:
                login(request, user)
                return redirect(getattr(settings, "AUTH_REDIRECT_LOGIN", "dashboard"))
    else:
        form = LoginForm()
    
        return render(request, "authentication/login.html", {"form": form})



def logout_view(request):
    logout(request)
    return redirect(getattr(settings, "AUTH_REDIRECT_LOGOUT", "login"))




def verify_otp(request):
    user_id = request.session.get("otp_user")
    if not user_id:
        return redirect("signup")

    user = CustomUser.objects.get(id=user_id)

    if request.method == "POST":
        form = OTPForm(request.POST)
        if form.is_valid():
            user_otp = form.cleaned_data["otp"]
            saved_otp = OTP.objects.filter(user=user, code=user_otp).first()

            if saved_otp and saved_otp.expires_at > now():
                user.is_active = True
                user.save()
                login(request, user)
                return redirect(getattr(settings, "AUTH_REDIRECT_OTP_VERIFIED", "dashboard"))
            else:
                return render(request, "authentication/verify_otp.html", {"form": form, "error": "Invalid OTP or expired."})
    else:
        form = OTPForm()

        return render(request, "authentication/verify_otp.html", {"form": form})


def dashboard(request):
    return render(request, "dashboard.html")